@@ -58,10 +58,22 @@ class Frame(object):
         self.iqueue = IntermediateMessageQueue()
         self.rqueue = Queue()
 
-    def connect(self, sock):
-        """Connect to the STOMP server and get the session id."""
+    def connect(self, sock, username=None, password=None):
+        """Connect to the STOMP server and get the session id.
+
+        :param sock: Socket object from stompy.stomp.Stomp
+        :keyword username: Username for connection
+        :keyword password: Password for connection
+
+        """
         self.sock = sock
-        frame = self.build_frame({"command": "CONNECT", "headers": {}})
+        if username and password:
+            frame = self.build_frame({"command": "CONNECT", 
+                                      "headers": {'login': username,
+                                                  'passcode': password}})
+        else:
+            frame = self.build_frame({"command": "CONNECT", "headers": {}})
+
         self.send_frame(frame.as_string())
 
         # Get session from the next reply from the server.
